.cf7r-meta-filter,.tablenav>.actions:not(.bulkactions){display:flex;flex-wrap:wrap;gap:5px}.cf7r-meta-filter input:last-child{flex-grow:1;max-width:250px}.cf7r-btn-export.button-primary{margin-left:20px;margin-top:8px}.column-data_preview{gap:5px}.cf7r-preview-data,.column-data_preview{display:flex;flex-direction:column}.cf7r-preview-data span:last-child{font-weight:bolder}#wpcf7r_leads>.inside{display:flex;flex-direction:column;gap:.75rem}#wpcf7r_leads .field-wrap{display:flex;flex-direction:column;gap:.25rem}#wpcf7r_leads .field-wrap label{align-items:flex-end;display:flex;flex-grow:1;justify-content:space-between}#wpcf7r_leads :is(.rcf7-download-btn,.rcf7-file-download-container){align-items:center;display:flex;flex-direction:row;gap:.25rem}#wpcf7r_leads .rcf7-file-download-container{gap:.5rem}#wpcf7r_leads .rcf-7-copy-field{line-height:0;text-decoration:none}#wpcf7r_leads .rcf7-file-error-container p{background-color:#f0f0f1;color:red;padding:1rem}#wpcf7r_leads :is(.rcf7-file-preview-container,.rcf7-file-error-container):empty{display:none}#poststuff{max-width:1200px}div.notice.themeisle-sale{margin-top:10px}
